# Copyright (c) 2000-2012, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

%bcond_without repolib

%define reltag _redhat_1
%define namedreltag -redhat-1
%global namedversion %{version}%{?namedreltag}

%define section free

Name:           rngom
Version:        201103
Release:        0.2%{?reltag}%{?dist}
Epoch:          0
Summary:        RELAX NG Object Model / Parser
License:        MIT-style
Group:          Development/Libraries/Java
URL:            https://rngom.dev.java.net/
%if 0
rm -rf rngom-201103.tar.bz2 rngom-201103
svn -q export -r '{20110406}' https://svn.java.net/svn/rngom~svn/trunk/rngom rngom-201103 && tar cjf rngom-201103.tar.bz2 rngom-201103
%endif
Source0:        rngom-201103.tar.bz2
Patch0:         rngom-pom.patch
Requires(post): jpackage-utils
Requires(postun): jpackage-utils
Requires:       java >= 0:1.5.0
Requires:       jpackage-utils
Requires:       relaxngDatatype
BuildRequires:  java-devel
BuildRequires:  jpackage-utils
BuildRequires:  maven2-plugin-antrun
BuildRequires:  maven2-plugin-clean
BuildRequires:  maven2-plugin-compiler
BuildRequires:  maven2-plugin-deploy
BuildRequires:  maven2-plugin-install
BuildRequires:  maven2-plugin-jar
BuildRequires:  maven2-plugin-resources
BuildRequires:  maven2-plugin-surefire
BuildRequires:  maven2-plugin-site
BuildRequires:  maven-surefire-provider-junit4
BuildRequires:  javacc-maven-plugin
BuildRequires:  jboss-parent
BuildRequires:  junit
BuildRequires:  xsdlib
BuildRequires:  relaxngDatatype
BuildRequires:  xmlunit
BuildArch:      noarch
BuildRoot:      %{_rmppath}/%{name}-%{version}-%{release}-root


%description
RNGOM is an open-source Java library for parsing RELAX NG 
grammars. In particular, RNGOM can:
1. parse the XML syntax
2. parse the compact syntax
3. check all the semantic restrictions as specified in the 
   specification
4. parse RELAX NG into application-defined data structures
5. build a default data structure based around the binarized 
   simple syntax or another data structure that preserves 
   more of the parsed information.
6. parse foreign elements/attributes in a schema
7. parse comments in a schema 

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation
Requires:       jpackage-utils

%description javadoc
%{summary}.

%if %with repolib
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:          Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
%setup -q
%patch0 -p1 -b .sav0

%build
export MAVEN_REPO_LOCAL=`pwd`/.m2/repository
export ALT_DEPLOYMENT_REPOSITORY=oss-releases::default::file://`pwd`/maven2-brew
export MAVEN_OPTS="-Xms1g -Xmx1g"
%{_bindir}/mvn-jpp -e -Dmaven.repo.local=${MAVEN_REPO_LOCAL} -DaltDeploymentRepository=${ALT_DEPLOYMENT_REPOSITORY} -Dmaven.test.failure.ignore deploy javadoc:aggregate

%install
%{__rm} -rf %{buildroot}

# jars
%{__mkdir_p} %{buildroot}%{_javadir}
%{__cp} -p maven2-brew/org/kohsuke/rngom/rngom/%{namedversion}/rngom-%{namedversion}-sources.jar %{buildroot}%{_javadir}/rngom-%{namedversion}-sources.jar
%{__cp} -p maven2-brew/org/kohsuke/rngom/rngom/%{namedversion}/rngom-%{namedversion}.jar %{buildroot}%{_javadir}/rngom-%{namedversion}.jar
(cd %{buildroot}%{_javadir} && for jar in *-%{namedversion}*; do %{__ln_s} ${jar} `/bin/echo ${jar} | %{__sed} -e "s|-%{namedversion}||g"`; done)

# poms
%{__mkdir_p} %{buildroot}%{_mavenpomdir}
%{__cp} -p maven2-brew/org/kohsuke/rngom/rngom/%{namedversion}/rngom-%{namedversion}.pom %{buildroot}%{_mavenpomdir}/JPP-rngom.pom

# depmaps
%add_to_maven_depmap org.kohsuke.rngom rngom %{namedversion} JPP rngom

# javadoc
%{__mkdir_p} %{buildroot}%{_javadocdir}/%{name}-%{namedversion}
%{__cp} -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}-%{namedversion}
%{__ln_s} %{name}-%{namedversion} %{buildroot}%{_javadocdir}/%{name}

# repolib
%if %with repolib
%{__mkdir_p} %{buildroot}%{_javadir}/repository.jboss.com/maven2-brew
%{__cp} -pr maven2-brew/* %{buildroot}%{_javadir}/repository.jboss.com/maven2-brew
%endif

%clean
%{__rm} -rf %{buildroot}

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(0644,root,root,0755)
%{_javadir}*/rngom-%{namedversion}-sources.jar
%{_javadir}*/rngom-sources.jar
%{_javadir}*/rngom-%{namedversion}.jar
%{_javadir}*/rngom.jar
%{_mavenpomdir}/JPP-rngom.pom
%{_mavendepmapfragdir}/rngom

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{namedversion}
%{_javadocdir}/%{name}

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%dir %{_javadir}*
%exclude %dir %{_javadocdir}
%{_javadir}*/repository.jboss.com
%endif

%changelog
* Tue Mar 27 2012 David Walluck <dwalluck@redhat.com> 0:201103-0.2
- add repolib

* Wed Feb 22 2012 David Walluck <dwalluck@redhat.com> 0:201103-0.1
- 201103
- use maven to build

* Tue Mar 11 2008 Ralph Apel <r.apel at r-apel.de> 0:0.1-0.20061207.1jpp
- 20061207 == jaxb21_fcs tag
